package App::PPH21Utils;

our $DATE = '2017-05-24'; # DATE
our $VERSION = '0.03'; # VERSION

1;
# ABSTRACT: CLI utilities related to Indonesian income tax article 21 ("PPH21")

__END__

=pod

=encoding UTF-8

=head1 NAME

App::PPH21Utils - CLI utilities related to Indonesian income tax article 21 ("PPH21")

=head1 VERSION

This document describes version 0.03 of App::PPH21Utils (from Perl distribution App-PPH21Utils), released on 2017-05-24.

=head1 DESCRIPTION

This distribution includes the following CLI utilities:

=over

=item * L<calc-net-income-from-pph21-op>

=item * L<calc-pph21-op>

=item * L<get-pph21-op-ptkp>

=item * L<get-pph21-op-rates>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-PPH21Utils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-PPH21Utils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PPH21Utils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Business::Tax::ID::PPH21>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
